<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca" sourcelanguage="en">
  <context>
    <name>CmdRobotAddToolShape</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="215"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="216"/>
      <source>Add tool</source>
      <translation>Afegir eina</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="217"/>
      <source>Add a tool shape to the robot</source>
      <translation>Afegeix una forma d'eina al robot</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="158"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="159"/>
      <source>Place robot...</source>
      <translation>Robot lloc...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="160"/>
      <source>Place a robot (experimental!)</source>
      <translation>Emplaça un robot (experimental!)</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotCreateTrajectory</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="62"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="63"/>
      <source>Create trajectory</source>
      <translation>Crear la trajectòria</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="64"/>
      <source>Create a new empty trajectory </source>
      <translation>Crear una nova trajectòria buida </translation>
    </message>
  </context>
  <context>
    <name>CmdRobotEdge2Trac</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="320"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="321"/>
      <source>Edge to Trajectory...</source>
      <translation>Vora de trajectòria...</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="322"/>
      <source>Generate a Trajectory from a set of edges</source>
      <translation>Generar una trajectòria d'un conjunt de vores</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotExportKukaCompact</name>
    <message>
      <location filename="../../CommandExport.cpp" line="50"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="51"/>
      <source>Kuka compact subroutine...</source>
      <translation>Kuka compacte subrutines...</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="52"/>
      <source>Export the trajectory as a compact KRL subroutine.</source>
      <translation>Exporta la trajectòria com un compacte subrutines KRL.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotExportKukaFull</name>
    <message>
      <location filename="../../CommandExport.cpp" line="112"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="113"/>
      <source>Kuka full subroutine...</source>
      <translation>Subrutina Kuka completa...</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="114"/>
      <source>Export the trajectory as a full KRL subroutine.</source>
      <translation>Exporta la trajectòria com una subrutina KRL.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR125</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="174"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="175"/>
      <source>Kuka IR125</source>
      <translation>Kuka IR125</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="176"/>
      <source>Insert a Kuka IR125 into the document.</source>
      <translation>Inserir un Kuka IR125 en el document.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR16</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="93"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="94"/>
      <source>Kuka IR16</source>
      <translation>Kuka IR16</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="95"/>
      <source>Insert a Kuka IR16 into the document.</source>
      <translation>Inserir un Kuka IR125 en el document.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR210</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="134"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="135"/>
      <source>Kuka IR210</source>
      <translation>Kuka IR210</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="136"/>
      <source>Insert a Kuka IR210 into the document.</source>
      <translation>Inserir un Kuka IR210 en el document.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR500</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="51"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="52"/>
      <source>Kuka IR500</source>
      <translation>Kuka IR500</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="53"/>
      <source>Insert a Kuka IR500 into the document.</source>
      <translation>Inserir un Kuka IR500 en el document.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertWaypoint</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="95"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="96"/>
      <source>Insert in trajectory</source>
      <translation>Inserir en la trajectòria</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="97"/>
      <source>Insert robot Tool location into trajectory</source>
      <translation>Inserir ubicació d'eina del robot a trajectòria</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertWaypointPreselect</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="152"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="153"/>
      <source>Insert in trajectory</source>
      <translation>Inserir en la trajectòria</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="154"/>
      <source>Insert preselection position into trajectory (W)</source>
      <translation>Inserir preselecció de posició en trajectòria (W)</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotRestoreHomePos</name>
    <message>
      <location filename="../../Command.cpp" line="104"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <location filename="../../Command.cpp" line="106"/>
      <source>Move to home</source>
      <translation>Desplaça-ho a casa</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetDefaultOrientation</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="216"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="217"/>
      <source>Set default orientation</source>
      <translation>Establir orientació per defecte</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="218"/>
      <source>Set the default orientation for subsequent commands for waypoint creation</source>
      <translation>Estableix l'orientació per defecte per a ordres posteriors per a la creació de fites</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetDefaultValues</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="254"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="255"/>
      <source>Set default values</source>
      <translation>Establir valors per defecte</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="256"/>
      <source>Set the default values for speed, acceleration and continuity for subsequent commands of waypoint creation</source>
      <translation>Estableix els valors per defecte de velocitat, acceleració i continuïtat per a ordres posteriors de creació de fites</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetHomePos</name>
    <message>
      <location filename="../../Command.cpp" line="55"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="56"/>
      <location filename="../../Command.cpp" line="57"/>
      <source>Set the home position</source>
      <translation>Estableix la posició de casa</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSimulate</name>
    <message>
      <location filename="../../Command.cpp" line="199"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="200"/>
      <source>Simulate a trajectory</source>
      <translation>Simular una trajectòria</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="201"/>
      <source>Run a simulation on a trajectory</source>
      <translation>Executar una simulació en una trajectòria</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotTrajectoryCompound</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="431"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="432"/>
      <source>Trajectory compound...</source>
      <translation>Trajectòria composta...</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="433"/>
      <source>Group and connect some trajectories to one</source>
      <translation>Agrupar i connectar algunes trajectòries a una</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotTrajectoryDressUp</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="384"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="385"/>
      <source>Dress-up trajectory...</source>
      <translation>Modificació de trajectòria...</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="386"/>
      <source>Create a dress-up object which overrides some aspects of a trajectory</source>
      <translation>Crear un objecte modificat que invalida alguns aspectes d'una trajectòria</translation>
    </message>
  </context>
  <context>
    <name>Gui::TaskView::TaskWatcherCommands</name>
    <message>
      <location filename="../../Workbench.cpp" line="53"/>
      <source>Trajectory tools</source>
      <translation>Eines de trajectòria</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="54"/>
      <source>Robot tools</source>
      <translation>Eines de robot</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="55"/>
      <source>Insert Robot</source>
      <translation>Insereix un Robot</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="75"/>
      <location filename="../../Command.cpp" line="124"/>
      <location filename="../../Command.cpp" line="224"/>
      <location filename="../../Command.cpp" line="253"/>
      <location filename="../../CommandExport.cpp" line="65"/>
      <location filename="../../CommandExport.cpp" line="127"/>
      <location filename="../../CommandInsertRobot.cpp" line="234"/>
      <location filename="../../CommandTrajectory.cpp" line="111"/>
      <location filename="../../CommandTrajectory.cpp" line="167"/>
      <location filename="../../CommandTrajectory.cpp" line="184"/>
      <location filename="../../CommandTrajectory.cpp" line="412"/>
      <source>Wrong selection</source>
      <translation>Selecció incorrecta</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="76"/>
      <source>Select one Robot to set home position</source>
      <translation>Seleccionar un Robot per establir la posició inicial</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="125"/>
      <source>Select one Robot</source>
      <translation>Seleccionar un Robot</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="225"/>
      <location filename="../../Command.cpp" line="254"/>
      <location filename="../../CommandExport.cpp" line="66"/>
      <location filename="../../CommandExport.cpp" line="128"/>
      <location filename="../../CommandTrajectory.cpp" line="112"/>
      <source>Select one Robot and one Trajectory object.</source>
      <translation>Seleccionar un Robot i un objecte de trajectòria.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="230"/>
      <source>Trajectory not valid</source>
      <translation>Trajectòria no vàlida</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="231"/>
      <source>You need at least two waypoints in a trajectory to simulate.</source>
      <translation>Necessiteu almenys dos punts de camí en una trajectòria per a la simulació.</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="88"/>
      <location filename="../../CommandExport.cpp" line="150"/>
      <source>KRL file</source>
      <translation>Arxiu KRL</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="89"/>
      <location filename="../../CommandExport.cpp" line="151"/>
      <source>All Files</source>
      <translation>Tots els fitxers</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="90"/>
      <location filename="../../CommandExport.cpp" line="152"/>
      <source>Export program</source>
      <translation>Programa d'exportació</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="235"/>
      <source>Select one robot and one shape or VRML object.</source>
      <translation>Seleccionar un robot i una forma o objecte VRML.</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="168"/>
      <location filename="../../CommandTrajectory.cpp" line="185"/>
      <source>Select one Trajectory object.</source>
      <translation>Seleccionar un objecte trajectòria.</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="191"/>
      <source>No preselection</source>
      <translation>Cap preselecció</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="192"/>
      <source>You have to hover above a geometry (Preselection) with the mouse to use this command. See documentation for details.</source>
      <translation>Ha de passar per sobre d'una geometria (preselecció) amb el ratolí per a utilitzar aquesta instrucció. Veure la documentació per a més detalls.</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="268"/>
      <source>Set default speed</source>
      <translation>Establir velocitat per defecte</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="269"/>
      <source>speed: (e.g. 1 m/s or 3 cm/s)</source>
      <translation>velocitat: (per exemple, 1 m/s o 3 cm/s)</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="278"/>
      <source>Set default continuity</source>
      <translation>Estableix la continuïtat per defecte</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="279"/>
      <source>continuous ?</source>
      <translation>continu?</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="285"/>
      <source>Set default acceleration</source>
      <translation>Estableix l'acceleració per defecte</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="286"/>
      <source>acceleration: (e.g. 1 m/s^2 or 3 cm/s^2)</source>
      <translation>acceleració: (per exemple, 1 m/s^2 o 3 cm/s^2)</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="413"/>
      <source>Select the Trajectory which you want to dress up.</source>
      <translation>Seleccionar la trajectòria que vol modificar.</translation>
    </message>
    <message>
      <location filename="../../ViewProviderTrajectory.cpp" line="164"/>
      <source>Modify</source>
      <translation>Modifica</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="81"/>
      <source>No robot files installed</source>
      <translation>No hi ha fitxers de robot instal·lats</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="82"/>
      <source>Please visit %1 and copy the files to %2</source>
      <translation>Si us plau visiti %1 i copiar els arxius a %2</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::DlgTrajectorySimulate</name>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="20"/>
      <source>Simulation</source>
      <translation>Simulació</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="58"/>
      <source>|&lt;</source>
      <translation>|&lt;</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="89"/>
      <source>&lt;</source>
      <translation>&lt;</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="120"/>
      <source>||</source>
      <translation>||</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="151"/>
      <source>|&gt;</source>
      <translation>|&gt;</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="182"/>
      <source>&gt;</source>
      <translation>&gt;</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="213"/>
      <source>&gt;|</source>
      <translation>&gt;|</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="237"/>
      <source>%</source>
      <translation>%</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="272"/>
      <source>Type</source>
      <translation>Tipus</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="277"/>
      <source>Name</source>
      <translation>Nom</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="282"/>
      <source>C</source>
      <translation>C</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="287"/>
      <source>V</source>
      <translation>V</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="292"/>
      <source>A</source>
      <translation>A</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskEdge2TracParameter</name>
    <message>
      <location filename="../../TaskEdge2TracParameter.cpp" line="47"/>
      <source>TaskEdge2TracParameter</source>
      <translation type="unfinished">TaskEdge2TracParameter</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobot6Axis</name>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="14"/>
      <source>Form</source>
      <translation>Forma</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="22"/>
      <source>A1</source>
      <translation>A1</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="69"/>
      <source>A2</source>
      <translation>A2</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="116"/>
      <source>A3</source>
      <translation>A3</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="163"/>
      <source>A4</source>
      <translation>A4</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="210"/>
      <source>A5</source>
      <translation>A5</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="257"/>
      <source>A6</source>
      <translation>A6</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="313"/>
      <source>TCP: (200.23,300.23,400.23,234,343,343)</source>
      <translation>TCP: (200.23,300.23,400.23,234,343,343)</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="329"/>
      <source>Tool: (0,0,400,0,0,0)</source>
      <translation>Eina: (0,0,400,0,0,0)</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="345"/>
      <source>...</source>
      <translation>...</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.cpp" line="52"/>
      <source>TaskRobot6Axis</source>
      <translation type="unfinished">TaskRobot6Axis</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobotControl</name>
    <message>
      <location filename="../../TaskRobotControl.cpp" line="46"/>
      <source>TaskRobotControl</source>
      <translation type="unfinished">TaskRobotControl</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobotMessages</name>
    <message>
      <location filename="../../TaskRobotMessages.cpp" line="46"/>
      <source>TaskRobotMessages</source>
      <translation type="unfinished">TaskRobotMessages</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskTrajectory</name>
    <message>
      <location filename="../../TaskTrajectory.ui" line="20"/>
      <source>Form</source>
      <translation>Forma</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="58"/>
      <source>|&lt;</source>
      <translation>|&lt;</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="89"/>
      <source>&lt;</source>
      <translation>&lt;</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="120"/>
      <source>||</source>
      <translation>||</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="151"/>
      <source>|&gt;</source>
      <translation>|&gt;</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="182"/>
      <source>&gt;</source>
      <translation>&gt;</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="213"/>
      <source>&gt;|</source>
      <translation>&gt;|</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="237"/>
      <source>%</source>
      <translation>%</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="254"/>
      <source>10 ms</source>
      <translation>10 ms</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="259"/>
      <source>50 ms</source>
      <translation>50 ms</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="264"/>
      <source>100 ms</source>
      <translation>100 ms</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="269"/>
      <source>500 ms</source>
      <translation>500 ms</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="274"/>
      <source>1 s</source>
      <translation>1 s</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="291"/>
      <source>Pos: (200.23, 300.23, 400.23, 234, 343 ,343)</source>
      <translation>Pos: (200.23, 300.23, 400.23, 234, 343, 343)</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="317"/>
      <source>Type</source>
      <translation>Tipus</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="322"/>
      <source>Name</source>
      <translation>Nom</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="327"/>
      <source>C</source>
      <translation>C</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="332"/>
      <source>V</source>
      <translation>V</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="337"/>
      <source>A</source>
      <translation>A</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.cpp" line="44"/>
      <source>Trajectory</source>
      <translation type="unfinished">Trajectory</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskTrajectoryDressUpParameter</name>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.cpp" line="48"/>
      <source>Dress Up Parameter</source>
      <translation type="unfinished">Dress Up Parameter</translation>
    </message>
  </context>
  <context>
    <name>TaskEdge2TracParameter</name>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="14"/>
      <source>Form</source>
      <translation>Forma</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="29"/>
      <source>Hide / Show</source>
      <translation>Amagar / Mostrar</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="47"/>
      <source>Edges: 0</source>
      <translation>Vores: 0</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="61"/>
      <source>Cluster: 0</source>
      <translation>Clúster: 0</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="72"/>
      <source>Sizing Value:</source>
      <translation>Valor de la dimensió:</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="103"/>
      <source>Use orientation of edge</source>
      <translation>Usar l'orientació de la vora</translation>
    </message>
  </context>
  <context>
    <name>TaskRobotControl</name>
    <message>
      <location filename="../../TaskRobotControl.ui" line="14"/>
      <source>Form</source>
      <translation>Forma</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="37"/>
      <source>X+</source>
      <translation>X+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="56"/>
      <source>Y+</source>
      <translation>Y+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="75"/>
      <source>Z+</source>
      <translation>Z+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="94"/>
      <source>A+</source>
      <translation>A+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="113"/>
      <source>B+</source>
      <translation>B+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="132"/>
      <source>C+</source>
      <translation>C+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="151"/>
      <source>X-</source>
      <translation>X-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="170"/>
      <source>Y-</source>
      <translation>Y-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="189"/>
      <source>Z-</source>
      <translation>Z-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="208"/>
      <source>A-</source>
      <translation>A-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="227"/>
      <source>B-</source>
      <translation>B-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="246"/>
      <source>C-</source>
      <translation>C-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="258"/>
      <source>Tool 0</source>
      <translation>Eina 0</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="263"/>
      <source>Tool</source>
      <translation>Eina</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="268"/>
      <source>Base 0</source>
      <translation>Base 0</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="273"/>
      <source>Base</source>
      <translation>Base</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="278"/>
      <source>World</source>
      <translation>Món</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="287"/>
      <source>50mm / 5°</source>
      <translation>50mm / 5°</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="292"/>
      <source>20mm / 2°</source>
      <translation>20mm / 2°</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="297"/>
      <source>10mm / 1°</source>
      <translation>10mm / 1°</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="302"/>
      <source>5mm / 0.5°</source>
      <translation>5mm / 0.5°</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="307"/>
      <source>1mm / 0.1°</source>
      <translation>1mm/0.1 º</translation>
    </message>
  </context>
  <context>
    <name>TaskRobotMessages</name>
    <message>
      <location filename="../../TaskRobotMessages.ui" line="14"/>
      <source>Form</source>
      <translation>Forma</translation>
    </message>
    <message>
      <location filename="../../TaskRobotMessages.ui" line="20"/>
      <source>clear</source>
      <translation>neteja</translation>
    </message>
  </context>
  <context>
    <name>TaskTrajectoryDressUpParameter</name>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="14"/>
      <source>Form</source>
      <translation>Forma</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="20"/>
      <source>Speed &amp; Acceleration:</source>
      <translation>Velocitat i Acceleració:</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="29"/>
      <source>Speed:</source>
      <translation>Velocitat:</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="55"/>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="92"/>
      <source>Use</source>
      <translation>Utilitza</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="66"/>
      <source>Accel:</source>
      <translation>Accel:</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="102"/>
      <source>Don't change Cont</source>
      <translation>No canviïs Cont</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="107"/>
      <source>Continues</source>
      <translation>Contínues</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="112"/>
      <source>Discontinues</source>
      <translation>Discontínues</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="127"/>
      <source>Position and Orientation:</source>
      <translation>Posició i Orientació:</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="136"/>
      <source>(0,0,0),(0,0,0)</source>
      <translation>(0,0,0),(0,0,0)</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="149"/>
      <source>...</source>
      <translation>...</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="159"/>
      <source>Don't change Position &amp; Orientation</source>
      <translation>No canviar la Posició ni l'Orientació</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="164"/>
      <source>Use Orientation</source>
      <translation>Utilitzar l'orientació</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="169"/>
      <source>Add Position</source>
      <translation>Afegir posició</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="174"/>
      <source>Add Orientation</source>
      <translation>Afegir l'orientació</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="49"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="50"/>
      <source>Insert Robots</source>
      <translation>Inserir Robots</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="51"/>
      <source>&amp;Robot</source>
      <translation>&amp;Robot</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="52"/>
      <source>Export trajectory</source>
      <translation>Exportar trajectòria</translation>
    </message>
  </context>
</TS>
